@@ -31,11 +31,12 @@ function AbstractPreferences(guiAction, appPreferences, initialClassName) {
 }
 
 AbstractPreferences.prototype = new Edit();
+AbstractPreferences.includeBasePath = includeBasePath;
 
 AbstractPreferences.prototype.beginEvent = function() {
     Edit.prototype.beginEvent.call(this);
     
-    this.dialog = this.createWidget("scripts/Edit/AbstractPreferences.ui");
+    this.dialog = this.createWidget(AbstractPreferences.includeBasePath + "/AbstractPreferences.ui");
     // TODO: Qt 5: add this flag (?)
     //var flags = new Qt.WindowFlags(Qt.WindowTitleHint);
     //this.dialog.setWindowFlags(flags);
@@ -186,7 +187,7 @@ AbstractPreferences.prototype.apply = function() {
         if (isNull(widget) || widget.hasChanged !== true) {
             continue;
         }
-        
+
         try {
             // include normally not needed
             var doInclude = false;
@@ -196,7 +197,7 @@ AbstractPreferences.prototype.apply = function() {
             if (doInclude) {
                 include(addOn.getFilePath());
             }
-            
+
             // apply application settings globally:
             if (this.appPreferences) {
                 if (!isNull(global[className]) && isFunction(global[className].applyPreferences)) {
@@ -234,6 +235,14 @@ AbstractPreferences.prototype.apply = function() {
     if (!isNull(di)) {
         di.regenerateScenes();
     }
+
+    var appWin = EAction.getMainWindow();
+    if (this.appPreferences) {
+        appWin.notifyPreferencesListeners(null);
+    }
+    else {
+        appWin.notifyPreferencesListeners(di);
+    }
 };
 
 /**
