@@ -222,7 +222,7 @@ ShapeAlgorithms.getOrthogonalTangents = function(line, circle) {
  * \param distance Distance of first parallel or concentric arc or circle.
  * \param number Number of offset shapes to generate.
  * \param sidePosition RVector indicating what side of the shape the parallels
- *         should be or RS.LeftHand or RS.RightHand or RS.BothSides.
+ *         should be RS.LeftHand or RS.RightHand or RS.BothSides.
  */
 ShapeAlgorithms.getOffsetShapes = function(shape, distance, number, sidePosition) {
     ShapeAlgorithms.error = undefined;
@@ -315,6 +315,14 @@ ShapeAlgorithms.getOffsetArcs = function(shape, distance, number, sidePosition)
                     insides.push(false);
                 }
             }
+            else {
+                if (sidePosition===RS.RightHand) {
+                    insides.push(true);
+                }
+                else {
+                    insides.push(false);
+                }
+            }
         }
     }
 
@@ -444,7 +452,13 @@ ShapeAlgorithms.getOffsetEllipses = function(shape, distance, number, sidePositi
             }
 
             if (isFullEllipseShape(shape)) {
-                spl.setPeriodic(true);
+                if (isSplineShape(spl)) {
+                    spl.setPeriodic(true);
+                }
+                else {
+                    // no ellipse proxy: offset curve is polyline:
+                    spl.setClosed(true);
+                }
             }
 
             ret.push(spl);
