@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2015 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -91,8 +91,7 @@ LibraryBrowser.initPreferences = function(pageWidget) {
     viewModeCombo.addItem(qsTr("Icon"), "Icon");
     viewModeCombo.addItem(qsTr("List"), "List");
 
-    var dirList = new DirectoryList(pageWidget, "SourceList",
-            qsTr("Choose Source Folder"));
+    var dirList = new DirectoryList(pageWidget, "SourceList", qsTr("Choose Source Folder"));
 };
 
 LibraryBrowser.applyPreferences = function(doc) {
@@ -122,6 +121,7 @@ LibraryBrowser.prototype.beginEvent = function() {
     var dock = appWin.findChild("LibraryBrowserDock");
     if (!QCoreApplication.arguments().contains("-no-show")) {
         dock.visible = !dock.visible;
+        if (dock.visible) dock.raise();
     }
 
     if (dock.visible) {
@@ -389,18 +389,18 @@ LibraryBrowser.updateFavoritesTab = function() {
 LibraryBrowser.initTagsTab = function() {
     var appWin = RMainWindowQt.getMainWindow();
     var formWidget = appWin.findChild("LibraryBrowserForm");
-    var tagsBrowser = appWin.findChild("TagsBrowser");
-    var webPage = tagsBrowser.page();
-    webPage.linkDelegationPolicy = QWebPage.DelegateAllLinks;
+//    var tagsBrowser = appWin.findChild("TagsBrowser");
+//    var webPage = tagsBrowser.page();
+//    webPage.linkDelegationPolicy = QWebPage.DelegateAllLinks;
 
     // make web view transparent:
-    var palette = tagsBrowser.palette;
-    palette.setBrush(QPalette.Base, new QColor(0,0,0,0));
-    webPage.palette = palette;
-    if (!RSettings.isQt(5)) {
-        tagsBrowser.setAttribute(Qt.WA_OpaquePaintEvent, false);
-    }
-    tagsBrowser.linkClicked.connect(LibraryBrowser, "linkClicked");
+//    var palette = tagsBrowser.palette;
+//    palette.setBrush(QPalette.Base, new QColor(0,0,0,0));
+//    webPage.palette = palette;
+//    if (!RSettings.isQt(5)) {
+//        tagsBrowser.setAttribute(Qt.WA_OpaquePaintEvent, false);
+//    }
+//    tagsBrowser.linkClicked.connect(LibraryBrowser, "linkClicked");
 
     var itemView =formWidget.findChild("TagsListView");
     var model = new QStandardItemModel(formWidget);
@@ -494,6 +494,9 @@ LibraryBrowser.linkClicked = function(url) {
  * \param force true: update HTML even if DB has not changed.
  */
 LibraryBrowser.updateTagsTab = function(force) {
+    // disabled:
+    return;
+
     if (force!==true) {
         var dbFileName = LibraryBrowser.getDbFileName();
         var dbMod = new QFileInfo(dbFileName).lastModified();
@@ -515,22 +518,16 @@ LibraryBrowser.updateTagsTab = function(force) {
 
     var mainFrame = tagsBrowser.page().mainFrame();
 
-    //var width = mainFrame.contentsSize.width() - 20;
     var width = tagsBrowser.page().viewportSize.width() - 20;
-//    qDebug("width:", width);
     var columns = Math.floor(width / 100);
-//    qDebug("columns:", columns);
     if (columns===0) {
         columns = 1;
     }
 
-//    var colWidth = 100/columns;
     var colWidth = Math.floor(width/columns) - 16;
-//    qDebug("colWidth:", colWidth);
 
     mainFrame.setScrollBarPolicy(Qt.Horizontal,Qt.ScrollBarAlwaysOff);
     mainFrame.setScrollBarPolicy(Qt.Vertical,Qt.ScrollBarAlwaysOn);
-    //var pos = mainFrame.scrollPosition;
 
     var categories = TagCategoryPeer.doSelectAll();
 
@@ -694,6 +691,9 @@ LibraryBrowser.updateTagsTab = function(force) {
 };
 
 LibraryBrowser.scrollTagsTab = function(fragment) {
+    // disabled:
+    return;
+
     var appWin = RMainWindowQt.getMainWindow();
     var tagsBrowser = appWin.findChild("TagsBrowser");
 
@@ -931,7 +931,7 @@ LibraryBrowser.getSelectedIndexes = function(selectionModel) {
     }
     else {
         // Qt 5:
-        return selectionModel.selectedIndexes;
+        return selectionModel.selection.indexes();
     }
 };
 
@@ -1965,7 +1965,7 @@ LibraryBrowser.showDirectory = function(dirName) {
     }
 
     var dirModel = dirTree.model();
-    var treeIndex = dirModel.index(dirName);
+    var treeIndex = dirModel.pathIndex(dirName);
     LibraryBrowser.deselectAllDirs();
     var selectionModel = dirTree.selectionModel();
     var flags = new QItemSelectionModel.SelectionFlags(QItemSelectionModel.Select);
@@ -1976,7 +1976,7 @@ LibraryBrowser.showDirectory = function(dirName) {
         treeIndex = treeIndex.parent();
         QCoreApplication.processEvents();
     }
-    treeIndex = dirModel.index(dirName);
+    treeIndex = dirModel.pathIndex(dirName);
     dirTree.scrollTo(treeIndex);
     listView.scrollToTop();
 };
